@@ -1,7 +1,7 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from base64 import decodestring
+from base64 import b64decode
 import os
 import re
 from warnings import warn
@@ -88,7 +88,7 @@ class RichJupyterWidget(RichIPythonWidget):
         format = self._control.cursorForPosition(pos).charFormat()
         name = format.stringProperty(QtGui.QTextFormat.ImageName)
         if name:
-            menu = QtGui.QMenu()
+            menu = QtGui.QMenu(self)
 
             menu.addAction('Copy Image', lambda: self._copy_image(name))
             menu.addAction('Save Image As...', lambda: self._save_image(name))
@@ -131,13 +131,15 @@ class RichJupyterWidget(RichIPythonWidget):
                 self._append_html(self.output_sep2, True)
             elif 'image/png' in data:
                 self._pre_image_append(msg, prompt_number)
-                png = decodestring(data['image/png'].encode('ascii'))
-                self._append_png(png, True, metadata=metadata.get('image/png', None))
+                png = b64decode(data['image/png'].encode('ascii'))
+                self._append_png(png, True, metadata=metadata.get('image/png',
+                                                                  None))
                 self._append_html(self.output_sep2, True)
             elif 'image/jpeg' in data and self._jpg_supported:
                 self._pre_image_append(msg, prompt_number)
-                jpg = decodestring(data['image/jpeg'].encode('ascii'))
-                self._append_jpg(jpg, True, metadata=metadata.get('image/jpeg', None))
+                jpg = b64decode(data['image/jpeg'].encode('ascii'))
+                self._append_jpg(jpg, True, metadata=metadata.get('image/jpeg',
+                                                                  None))
                 self._append_html(self.output_sep2, True)
             elif 'text/latex' in data:
                 self._pre_image_append(msg, prompt_number)
@@ -166,10 +168,10 @@ class RichJupyterWidget(RichIPythonWidget):
             elif 'image/png' in data:
                 # PNG data is base64 encoded as it passes over the network
                 # in a JSON structure so we decode it.
-                png = decodestring(data['image/png'].encode('ascii'))
+                png = b64decode(data['image/png'].encode('ascii'))
                 self._append_png(png, True, metadata=metadata.get('image/png', None))
             elif 'image/jpeg' in data and self._jpg_supported:
-                jpg = decodestring(data['image/jpeg'].encode('ascii'))
+                jpg = b64decode(data['image/jpeg'].encode('ascii'))
                 self._append_jpg(jpg, True, metadata=metadata.get('image/jpeg', None))
             elif 'text/latex' in data and latex_to_png:
                 try:
@@ -213,11 +215,18 @@ class RichJupyterWidget(RichIPythonWidget):
     def _append_latex(self, latex, before_prompt=False, metadata=None):
         """ Append latex data to the widget."""
         png = None
+
         if self._is_latex_math(latex):
             png = latex_to_png(latex, wrap=False, backend='dvipng')
+
+        # Matplotlib only supports strings enclosed in dollar signs
         if png is None and latex.startswith('$') and latex.endswith('$'):
-            # matplotlib only supports strings enclosed in dollar signs
-            png = latex_to_png(latex, wrap=False, backend='matplotlib')
+            # To avoid long and ugly errors, like the one reported in
+            # spyder-ide/spyder#7619
+            try:
+                png = latex_to_png(latex, wrap=False, backend='matplotlib')
+            except Exception:
+                pass
 
         if png:
             self._append_png(png, before_prompt, metadata)
@@ -357,11 +366,13 @@ class RichJupyterWidget(RichIPythonWidget):
             image = QtGui.QImage()
             image.loadFromData(img, fmt.upper())
             if width and height:
-                image = image.scaled(width, height, transformMode=QtCore.Qt.SmoothTransformation)
+                image = image.scaled(width, height,
+                                     QtCore.Qt.IgnoreAspectRatio,
+                                     QtCore.Qt.SmoothTransformation)
             elif width and not height:
-                image = image.scaledToWidth(width, transformMode=QtCore.Qt.SmoothTransformation)
+                image = image.scaledToWidth(width, QtCore.Qt.SmoothTransformation)
             elif height and not width:
-                image = image.scaledToHeight(height, transformMode=QtCore.Qt.SmoothTransformation)
+                image = image.scaledToHeight(height, QtCore.Qt.SmoothTransformation)
         except ValueError:
             self._insert_plain_text(cursor, 'Received invalid %s data.'%fmt)
         else:
@@ -397,10 +408,11 @@ class RichJupyterWidget(RichIPythonWidget):
             image.save(filename, format)
 
 
-# clobber RichIPythonWidget above:
+# Clobber RichIPythonWidget above:
 
 class RichIPythonWidget(RichJupyterWidget):
-    """Deprecated class. Use RichJupyterWidget"""
+    """Deprecated class. Use RichJupyterWidget."""
     def __init__(self, *a, **kw):
-        warn("RichIPythonWidget is deprecated, use RichJupyterWidget")
+        warn("RichIPythonWidget is deprecated, use RichJupyterWidget",
+             DeprecationWarning)
         super(RichIPythonWidget, self).__init__(*a, **kw)
